==> aspell-0.51-20040227.tar.gz: aspell-0.51-20040227/common/dictionary.hpp <==
// Copyright 2000 by Kevin Atkinson under the terms of the LGPL

#ifndef ASPELLER_DATA__HPP
#define ASPELLER_DATA__HPP

#include <assert.h>

#include "copy_ptr.hpp"
#include "enumeration.hpp"
#include "language.hpp"
#include "posib_err.hpp"
#include "string.hpp"
#include "string_enumeration.hpp"
#include "word_list.hpp"
#include "cache.hpp"
#include "wordinfo.hpp"

using namespace acommon;

namespace acommon {
  class Config;
  class FStream;
  class OStream;
  class Convert;
}

namespace aspeller {

  struct LocalDict;
  struct LocalDictInfo;
  class LocalDictList;
  typedef Enumeration<WordEntry *> WordEntryEnumeration;
  typedef Enumeration<const LocalDict *> DictsEnumeration;

  class SoundslikeEnumeration 
  {
  public:
    virtual WordEntry * next(int) = 0;
    virtual ~SoundslikeEnumeration() {}
    SoundslikeEnumeration() {}
  private:
    SoundslikeEnumeration(const SoundslikeEnumeration &);
    void operator=(const SoundslikeEnumeration &);
  };

  class Dictionary : public Cacheable, public WordList {

    virtual ~Dictionary();

    const Language * language() const = 0;
    const char * lang_name() const = 0;

    const char * file_name() const {return file_name_.path.c_str();}
    // returns any additional dictionaries that are also used
    virtual PosibErr<void> load(ParmString, const Config &) = 0;

    // FIXME: do I need all these?????
    virtual PosibErr<void> merge(ParmString) = 0;
    virtual PosibErr<void> synchronize() = 0;
    virtual PosibErr<void> save_noupdate() = 0;
    virtual PosibErr<void> save_as(ParmString) = 0;
    virtual PosibErr<void> clear() = 0;

    StringEnumeration * elements() const;

    virtual WordEntryEnumeration * detailed_elements() const = 0;
    virtual size_t size()     const;
    virtual bool   empty()    const;
  
    virtual bool lookup(ParmString word, WordEntry &) const = 0;
    
    virtual bool stripped_lookup(ParmString, WordEntry &) const = 0;

    virtual bool soundslike_lookup(ParmString, WordEntry & o) const = 0;

    // the elements returned are only guaranteed to remain valid
    // guaranteed to return all soundslike and all words 
    // however an individual soundslike may appear multiple
    // times in the list....
    virtual SoundslikeEnumeration * soundslike_elements() const = 0;

    virtual PosibErr<void> add(ParmString w) = 0;

    virtual PosibErr<void> remove(ParmString w) = 0;

    virtual bool repl_lookup(ParmString, WordEntry &) const = 0;

    PosibErr<void> add_repl(ParmString mis, ParmString cor) = 0;

    virtual PosibErr<void> remove_repl(ParmString mis, ParmString cor) = 0;

    virtual DictsEnumeration * dictionaries() const = 0;
  };

  typedef Dictionary Dict;
  typedef Dictionary ReplacementDict;
  typedef Dictionary MultiDict;

  bool operator==(const Dictionary::Id & rhs, const Dictionary::Id & lhs);

  inline bool operator!=(const  Dictionary::Id & rhs, const Dictionary::Id & lhs)
  {
    return !(rhs == lhs);
  }

  typedef unsigned int DataType;
  static const DataType DT_ReadOnly     = 1<<0;
  static const DataType DT_Writable     = 1<<1;
  static const DataType DT_WritableRepl = 1<<2;
  static const DataType DT_Multi        = 1<<3;
  static const DataType DT_Any          = 0xFF;

  // stores result in LocalDict
  // any new extra dictionaries that were loaded will be ii
  PosibErr<void> add_data_set(ParmString file_name,
                              const Config &,
                              LocalDict &,
                              LocalDictList * other_dicts = 0,
                              SpellerImpl * = 0,
                              const LocalDictInfo * local_info = 0,
                              ParmString dir = 0,
                              DataType allowed = DT_Any);
  
  // implemented in readonly_ws.cc
  Dictionary * new_default_readonly_dict();
  
  PosibErr<void> create_default_readonly_dict(StringEnumeration * els,
                                              Config & config);
  
  // implemented in multi_ws.cc
  MultiDict * new_default_multi_dict();

  // implemented in writable.cpp
  Dictionary * new_default_writable_dict();

  // implemented in writable.cpp
  ReplacementDict * new_default_replacement_dict();
}

#endif

==> aspell-0.60-20040624.tar.gz: aspell-0.60-20040624/common/dictionary.hpp <==
// Copyright 2000 by Kevin Atkinson under the terms of the LGPL

#ifndef ASPELLER_DATA__HPP
#define ASPELLER_DATA__HPP

#include <assert.h>

#include "copy_ptr.hpp"
#include "enumeration.hpp"
#include "language.hpp"
#include "posib_err.hpp"
#include "string.hpp"
#include "string_enumeration.hpp"
#include "word_list.hpp"
#include "cache.hpp"
#include "wordinfo.hpp"

using namespace acommon;

namespace acommon {
  class Config;
  class FStream;
  class OStream;
  class Convert;
}

namespace aspeller {

  class Dictionary;
  struct SensitiveCompare {};

  struct LocalDict 
  {
    Dictionary * dict;
    const SensitiveCompare * compare;
  };

  typedef Enumeration<WordEntry *> WordEntryEnumeration;
  typedef Enumeration<const LocalDict *> DictsEnumeration;

  class Dictionary : public Cacheable, public WordList {

    virtual ~Dictionary();

    const Language * language() const = 0;
    const char * lang_name() const = 0;

    const char * file_name() const {return file_name_.path.c_str();}
    // returns any additional dictionaries that are also used
    virtual PosibErr<void> load(ParmString, const Config &) = 0;

    // FIXME: do I need all these?????
    virtual PosibErr<void> merge(ParmString) = 0;
    virtual PosibErr<void> synchronize() = 0;
    virtual PosibErr<void> save_noupdate() = 0;
    virtual PosibErr<void> save_as(ParmString) = 0;
    virtual PosibErr<void> clear() = 0;

    StringEnumeration * elements() const;

    virtual WordEntryEnumeration * detailed_elements() const = 0;
    virtual size_t size()     const;
    virtual bool   empty()    const;
  
    virtual bool lookup(ParmString word, WordEntry &, 
                        const SensitiveCompare &) const = 0;
    
    virtual bool stripped_lookup(ParmString, WordEntry &) const = 0;

    virtual bool soundslike_lookup(ParmString, WordEntry & o) const = 0;

    virtual PosibErr<void> add(ParmString w) = 0;

    virtual PosibErr<void> remove(ParmString w) = 0;

    virtual bool repl_lookup(ParmString, WordEntry &) const = 0;

    PosibErr<void> add_repl(ParmString mis, ParmString cor) = 0;

    virtual PosibErr<void> remove_repl(ParmString mis, ParmString cor) = 0;

    virtual DictsEnumeration * dictionaries() const = 0;
  };

  bool operator==(const Dictionary::Id & rhs, const Dictionary::Id & lhs);

  inline bool operator!=(const  Dictionary::Id & rhs, const Dictionary::Id & lhs)
  {
    return !(rhs == lhs);
  }

  // stores result in LocalDict
  // any new extra dictionaries that were loaded will be ii
  PosibErr<LocalDict *> new_dict(ParmString file_name, const Config &);

  // implemented in readonly_ws.cc
  Dictionary * new_default_readonly_dict();
  
  PosibErr<void> create_default_readonly_dict(StringEnumeration * els,
                                              Config & config);
  
  // implemented in multi_ws.cc
  MultiDict * new_default_multi_dict();

  // implemented in writable.cpp
  Dictionary * new_default_writable_dict();

  // implemented in writable.cpp
  ReplacementDict * new_default_replacement_dict();
}

#endif
